#!/bin/sh
#
# gogo6     This script takes care of starting and stopping gogoc tunneling
#              client.
#
# Author: J. Randall Owens <jrowens@ghiapet.net>
#
# chkconfig:   345 90 10
# description: IPv6 Tunneling client required for IPv6 connectivity with Freenet6


### BEGIN INIT INFO
# Provides:    gogo6
# Required-Start: $network
# Required-Stop: $network
# Default-Start: 3 4 5
# Default-Stop: 0 1 2 6
# Short-Description: gogo6 tunneling client. 
# Description: IPv6 Tunneling client required for IPv6 connectivity with Freenet6
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

# LSB init routines
. /lib/lsb/init-functions

# Source networking configuration.
. /etc/sysconfig/network

# Check that networking is up.
[ "$NETWORKING" = "no" ] && exit 0

exec=/usr/bin/gogoc
prog=$(basename $exec)

GOGOC_CONFIG_FILENAME=/etc/gogoc/gogoc.conf

[ -e /etc/sysconfig/$prog ] && . /etc/sysconfig/$prog
pidfile=/var/run/$prog.pid
lockfile=/var/lock/subsys/$prog

pid=0
getpid() {
	pid=$(ps -Ao pid,cmd |fgrep $exec |fgrep -v grep |awk '{ print $1 }')
}

start() {
    echo -n $"Starting $prog: "
    # start it up here, usually something like "daemon $exec"
	getpid
	if [ -z "$pid" ]; then
	    $exec -f ${GOGOC_CONFIG_FILENAME} ${GOGOC_OPTS} 2>/dev/null >/dev/null
		retval=$?
		getpid
		[ $retval -eq 0 ] && echo $pid >>${pidfile}
    	[ $retval -eq 0 ] && touch $lockfile
    	( [ $retval -eq 0 ] &&  success ) || failure
	else
		retval=0
	fi
    echo
    return $retval
}

stop() {
    echo -n $"Stopping $prog: "
    # stop it here, often "killproc $prog"
    killproc -p $pidfile $prog 15
    retval=$?
    ([ $retval -eq 0 ] && rm -f $lockfile && rm -f $pidfile && success ) || failure
    echo
    return $retval
}

restart() {
    stop
    start
}

reload() {
    restart
}

force_reload() {
    restart
}

fdr_status() {
    status $prog
}

case "$1" in
    start|stop|restart|reload)
        $1
        ;;
    force-reload)
        force_reload
        ;;
    status)
        fdr_status
        ;;
    condrestart|try-restart)
  	[ ! -f $lockfile ] || restart
	;;
    *)
        echo $"Usage: $0 {start|stop|status|restart|try-restart|reload|force-reload}"
        exit 2
esac
